import React, { useEffect, useState } from 'react';
import { Box, VStack, Heading, Textarea, Button, Select, Text } from '@chakra-ui/react';
import DocumentTitle from '@/components/system/pages/DocumentTitle';
import PageContainer from '@/components/system/PageContainer';
import DashboardBackground from '@/components/system/pages/DashboardBackground';
import FadeInWrapper from '@/components/system/layout/FadeInWrapper';
import ConfigTool from '@/libs/config/ConfigTool';
import { api } from '@/services/api/api';
import Notification from '@/libs/system/Notification';

const ConfigPage = () => {
  const [devices, setDevices] = useState([]);
  const [selectedDevice, setSelectedDevice] = useState('');
  const [inputText, setInputText] = useState('');
  const [parsedConfig, setParsedConfig] = useState('');
  const [loading, setLoading] = useState(false);

  useEffect(() => {
    const config = ConfigTool.load();
    setDevices(config.devices || []);
  }, []);

  const handleParse = async () => {
    if (!selectedDevice || !inputText) {
      Notification.error({ title: '请选择设备并输入配置指令' });
      return;
    }
    setLoading(true);
    try {
      const res = await api.parseCommand(inputText);
      setParsedConfig(res.config);
    } catch (e) {
      Notification.error({ title: '配置解析失败' });
    }
    setLoading(false);
  };

  const handleApply = async () => {
    if (!parsedConfig) return;
    setLoading(true);
    try {
      await api.applyConfig(selectedDevice, parsedConfig);
      Notification.success({ title: '配置已成功应用！' });
    } catch (e) {
      Notification.error({ title: '配置应用失败' });
    }
    setLoading(false);
  };

  return (
    <DocumentTitle title={'交换机配置'}>
      <DashboardBackground />
      <PageContainer>
        <FadeInWrapper delay={0.3} yOffset={-5}>
          <VStack spacing={8} align={'stretch'}>
            <Heading fontSize={'2xl'} color={'teal.300'}>
              {'交换机配置中心'}
            </Heading>

            <Select
              placeholder={'请选择交换机设备'}
              value={selectedDevice}
              onChange={(e) => setSelectedDevice(e.target.value)}
              bg={'whiteAlpha.200'}
            >
              {devices.map((device) => (
                <option key={device.ip} value={device.ip}>
                  {device.name} ({device.ip})
                </option>
              ))}
            </Select>

            <Textarea
              rows={6}
              placeholder={'输入自然语言配置指令...'}
              value={inputText}
              onChange={(e) => setInputText(e.target.value)}
              bg={'whiteAlpha.200'}
            />

            <Button
              colorPalette={'teal'}
              variant={'solid'}
              isLoading={loading}
              onClick={handleParse}
            >
              {'解析配置'}
            </Button>

            {parsedConfig && (
              <Box
                p={4}
                bg={'whiteAlpha.100'}
                borderRadius={'xl'}
                border={'1px solid'}
                borderColor={'whiteAlpha.300'}
              >
                <Text fontWeight={'bold'} mb={2}>
                  {'已生成配置:'}
                </Text>
                <Textarea value={parsedConfig} rows={8} readOnly />
                <Button mt={4} colorPalette={'teal'} onClick={handleApply}>
                  {'应用到交换机'}
                </Button>
              </Box>
            )}
          </VStack>
        </FadeInWrapper>
      </PageContainer>
    </DocumentTitle>
  );
};

export default ConfigPage;
