import React, { useEffect, useState } from 'react';
import {
  Box,
  VStack,
  Heading,
  Input,
  Button,
  Text,
  Spinner,
  Badge,
  HStack,
} from '@chakra-ui/react';
import { Table } from '@chakra-ui/react';
import DocumentTitle from '@/components/system/pages/DocumentTitle';
import PageContainer from '@/components/system/PageContainer';
import DashboardBackground from '@/components/system/pages/DashboardBackground';
import FadeInWrapper from '@/components/system/layout/FadeInWrapper';
import { api } from '@/services/api/api';
import ConfigTool from '@/libs/config/ConfigTool';
import Common from '@/libs/common';
import Notification from '@/libs/system/Notification';

/**
 * 网络扫描页面
 * @returns {JSX.Element}
 * @constructor
 */
const ScanPage = () => {
  const [subnet, setSubnet] = useState('');
  const [devices, setDevices] = useState([]);
  const [loading, setLoading] = useState(false);
  const [localIp, setLocalIp] = useState('');

  const config = ConfigTool.load();
  const testMode = config.testMode;

  useEffect(() => {
    const fetchLocalInfo = async () => {
      setLocalIp('172.17.99.208');
      if (!subnet) {
        const ipParts = '172.17.99.208'.split('.');
        setSubnet(`${ipParts[0]}.${ipParts[1]}.${ipParts[2]}.0/24`);
      }
    };
    fetchLocalInfo();
  }, [subnet, Notification]);

  const getTestDevices = () => {
    return [
      { ip: '192.168.1.1', mac: '00:1A:2B:3C:4D:5E', ports: [22, 23, 161] },
      { ip: '192.168.1.2', mac: '00:1D:7D:AA:1B:01', ports: [22, 23, 161] },
      { ip: '192.168.1.3', mac: '00:0C:29:5A:3B:11', ports: [22, 23, 161, 443] },
      { ip: '192.168.1.4', mac: '00:23:CD:FF:10:02', ports: [22, 23] },
      { ip: '192.168.1.5', mac: '00:04:4B:AA:BB:CC', ports: [22, 23, 80, 443] },
      { ip: '192.168.1.6', mac: '00:11:22:33:44:55', ports: [22, 23, 161] },
      { ip: '192.168.1.7', mac: '00:1F:45:67:89:AB', ports: [23] },
      { ip: '192.168.1.8', mac: '00:50:56:11:22:33', ports: [22, 443, 8443] },
    ];
  };

  const handleScan = async () => {
    setLoading(true);
    try {
      let scanDevices;
      if (testMode) {
        await Common.sleep(2000);
        scanDevices = getTestDevices();
      } else {
        const res = await api.scan(subnet);
        scanDevices = res.devices || [];
      }

      scanDevices = scanDevices.map((d, idx) => ({
        ...d,
        name: `交换机 ${idx + 1}`,
      }));
      setDevices(scanDevices);
      const updatedStats = {
        totalDevices: scanDevices.length,
        onlineDevices: scanDevices.length,
        lastScan: new Date().toISOString(),
      };

      ConfigTool.save({
        ...config,
        stats: updatedStats,
        devices: scanDevices,
      });
    } catch (err) {
      Notification.error({ title: '扫描网络失败' });
    }
    setLoading(false);
  };

  const handleLastScan = async () => {
    setLoading(true);
    try {
      let scanDevices;
      if (testMode) {
        await Common.sleep(2000);
        scanDevices = getTestDevices();
      } else {
        const res = await api.listDevices();
        scanDevices = res.devices || [];
      }
      setDevices(scanDevices);
    } catch (err) {
      Notification.error({ title: '获取上次扫描记录失败' });
    }
    setLoading(false);
  };

  return (
    <DocumentTitle title={'网络扫描'}>
      <DashboardBackground />
      <PageContainer>
        <FadeInWrapper delay={0.3} yOffset={-5}>
          <VStack spacing={8} align={'stretch'}>
            <Box
              p={6}
              bg={'whiteAlpha.100'}
              borderRadius={'xl'}
              border={'1px solid'}
              borderColor={'whiteAlpha.300'}
              mx={4}
              transition={'all 0.2s'}
              _hover={{ transform: 'translateY(-4px)' }}
            >
              <Heading fontSize={'2xl'} mb={4} color={'teal.300'}>
                {'网络扫描'}
              </Heading>

              <HStack mb={4}>
                <Text fontWeight={'medium'}>{'后端服务器IP: '}</Text>
                <Badge colorPalette={'blue'}>{localIp}</Badge>
              </HStack>

              <HStack mb={4} spacing={4}>
                <Input
                  placeholder={'输入子网 (如 192.168.1.0/24)'}
                  value={subnet}
                  onChange={(e) => setSubnet(e.target.value)}
                  width={'300px'}
                  bg={'whiteAlpha.200'}
                />
                <Button
                  onClick={handleScan}
                  isLoading={loading}
                  colorPalette={'teal'}
                  variant={'solid'}
                >
                  {'开始扫描'}
                </Button>
                <Button
                  onClick={handleLastScan}
                  isLoading={loading}
                  colorPalette={'blue'}
                  variant={'outline'}
                >
                  {'显示上次结果'}
                </Button>
              </HStack>

              {loading && (
                <HStack>
                  <Spinner />
                  <Text>{'正在加载，请稍候...'}</Text>
                </HStack>
              )}

              {!loading && devices.length > 0 && (
                <FadeInWrapper delay={0.2} yOffset={-5}>
                  <Table.Root
                    variant={'outline'}
                    colorPalette={'teal'}
                    size={'md'}
                    striped={'false'}
                    showColumnBorder={'true'}
                    interactive={'true'}
                    stickyHeader={'true'}
                    mt={4}
                    borderRadius={'lg'}
                    overflow={'hidden'}
                    shadow={'lg'}
                  >
                    <Table.Header bg={'transparent'}>
                      <Table.Row>
                        <Table.ColumnHeader bg={'whiteAlpha.100'} backdropFilter={'blur(4px)'}>
                          {'IP 地址'}
                        </Table.ColumnHeader>
                        <Table.ColumnHeader bg={'whiteAlpha.100'} backdropFilter={'blur(4px)'}>
                          {'MAC 地址'}
                        </Table.ColumnHeader>
                        <Table.ColumnHeader bg={'whiteAlpha.100'} backdropFilter={'blur(4px)'}>
                          {'开放端口'}
                        </Table.ColumnHeader>
                      </Table.Row>
                    </Table.Header>
                    <Table.Body>
                      {devices.map((d) => (
                        <Table.Row
                          key={d.ip}
                          _hover={{
                            bgGradient: 'linear(to-r, teal.50, blue.50)',
                            transition: 'background 0.3s ease',
                          }}
                        >
                          <Table.Cell>{d.ip}</Table.Cell>
                          <Table.Cell>{d.mac}</Table.Cell>
                          <Table.Cell>{d.ports.join(', ')}</Table.Cell>
                        </Table.Row>
                      ))}
                    </Table.Body>
                  </Table.Root>
                </FadeInWrapper>
              )}

              {!loading && devices.length === 0 && (
                <Text color={'gray.400'}>{'暂无扫描结果，请执行扫描。'}</Text>
              )}
            </Box>
          </VStack>
        </FadeInWrapper>
      </PageContainer>
    </DocumentTitle>
  );
};

export default ScanPage;
